Built-in Datasets
=================


.. automodule:: cornac.datasets
    :members:

Amazon Clothing
-----------------------------------------------
.. automodule:: cornac.datasets.amazon_clothing
   :members:

Amazon Digital Music
-----------------------------------------------
.. automodule:: cornac.datasets.amazon_digital_music
   :members:

Amazon Office
---------------------------------------------
.. automodule:: cornac.datasets.amazon_office
   :members:

Amazon Toys and Games
---------------------------------------------
.. automodule:: cornac.datasets.amazon_toy
   :members:

CiteULike
-----------------------------------------
.. automodule:: cornac.datasets.citeulike
   :members:

Epinions
-----------------------------------------
.. automodule:: cornac.datasets.epinions
   :members:

FilmTrust
---------------------------------------------
.. automodule:: cornac.datasets.filmtrust
   :members:

MovieLens
-----------------------------------------
.. automodule:: cornac.datasets.movielens
   :members:

Netflix
---------------------------------------
.. automodule:: cornac.datasets.netflix
   :members:

Tradesy
---------------------------------------
.. automodule:: cornac.datasets.tradesy
   :members:

